@@ -46,8 +46,6 @@
 #include "xua_internal.h"
 #include <osmocom/sigtran/sccp_sap.h>
 #include "sccp_internal.h"
-#include "ss7_route.h"
-#include "ss7_route_table.h"
 #include "ss7_internal.h"
 
 #include <netinet/tcp.h>
@@ -69,20 +67,6 @@
 	"SCTP (Stream Control Transmission Protocol)\n" \
 	"TCP (Transmission Control Protocol)\n"
 
-#define QOS_CLASS_RANGE_STR "<0-7>"
-#define QOS_CLASS_RANGE_HELP_STR "QoS Class\n"
-#define QOS_CLASS_VAR_STR "(" QOS_CLASS_RANGE_STR "|default)"
-#define QOS_CLASS_VAR_HELP_STR \
-	QOS_CLASS_RANGE_HELP_STR \
-	"Default QoS Class (0)\n"
-
-#define ROUTE_PRIO_RANGE_STR "<1-9>"
-#define ROUTE_PRIO_RANGE_HELP_STR "Priority\n"
-#define ROUTE_PRIO_VAR_STR "(" ROUTE_PRIO_RANGE_STR "|default)"
-#define ROUTE_PRIO_VAR_HELP_STR \
-	ROUTE_PRIO_RANGE_HELP_STR \
-	"Default Priority (5)\n"
-
 /* netinet/tcp.h */
 static const struct value_string tcp_info_state_values[] = {
 	{ TCP_ESTABLISHED,	"ESTABLISHED" },
@@ -250,23 +234,7 @@ DEFUN_ATTR(cs7_point_code, cs7_point_code_cmd,
 	return CMD_SUCCESS;
 }
 
-DEFUN_ATTR(cs7_secondary_pc, cs7_secondary_pc_cmd,
-	   "secondary-pc POINT_CODE",
-	   "Configure the local Secondary Point Code\n"
-	   "Point Code\n",
-	   CMD_ATTR_IMMEDIATE)
-{
-	struct osmo_ss7_instance *inst = vty->index;
-	int pc = osmo_ss7_pointcode_parse(inst, argv[0]);
-	if (pc < 0 || !osmo_ss7_pc_is_valid((uint32_t)pc)) {
-		vty_out(vty, "Invalid point code (%s)%s", argv[0], VTY_NEWLINE);
-		return CMD_WARNING;
-	}
-
-	inst->cfg.secondary_pc = pc;
-	return CMD_SUCCESS;
-}
-
+/* TODO: cs7 secondary-pc */
 /* TODO: cs7 capability-pc */
 DEFUN_ATTR(cs7_permit_dyn_rkm, cs7_permit_dyn_rkm_cmd,
 	   "xua rkm routing-key-allocation (static-only|dynamic-permitted)",
@@ -357,7 +325,7 @@ DEFUN_ATTR(cs7_route_table, cs7_route_table_cmd,
 }
 
 DEFUN_ATTR(cs7_rt_upd, cs7_rt_upd_cmd,
-	   "update route POINT_CODE MASK linkset LS_NAME [priority] [" ROUTE_PRIO_VAR_STR "] [qos-class] [" QOS_CLASS_VAR_STR "]",
+	   "update route POINT_CODE MASK linkset LS_NAME [priority] [PRIO] [qos-class] [(CLASS|default)]",
 	   "Update the Route\n"
 	   "Update the Route\n"
 	   "Destination Point Code\n"
@@ -365,9 +333,10 @@ DEFUN_ATTR(cs7_rt_upd, cs7_rt_upd_cmd,
 	   "Specify Destination Linkset\n"
 	   "Linkset Name\n"
 	   "Specify Priority\n"
-	   ROUTE_PRIO_VAR_HELP_STR
+	   "Priority\n"
 	   "Specify QoS Class\n"
-	   QOS_CLASS_VAR_HELP_STR,
+	   "QoS Class\n"
+	   "Default QoS Class\n",
 	   CMD_ATTR_IMMEDIATE)
 {
 	struct osmo_ss7_route_table *rtable = vty->index;
@@ -376,7 +345,6 @@ DEFUN_ATTR(cs7_rt_upd, cs7_rt_upd_cmd,
 	int mask = osmo_ss7_pointcode_parse_mask_or_len(rtable->inst, argv[1]);
 	const char *ls_name = argv[2];
 	unsigned int argind;
-	int rc;
 
 	if (dpc < 0) {
 		vty_out(vty, "%% Invalid point code (%s)%s", argv[0], VTY_NEWLINE);
@@ -388,9 +356,16 @@ DEFUN_ATTR(cs7_rt_upd, cs7_rt_upd_cmd,
 		return CMD_WARNING;
 	}
 
+	rt = osmo_ss7_route_create(rtable, dpc, mask, ls_name);
+	if (!rt) {
+		vty_out(vty, "%% Cannot create route %s/%s to %s%s",
+			argv[0], argv[1], argv[2], VTY_NEWLINE);
+		return CMD_WARNING;
+	}
+
 	switch (argc) {
 	case 3:
-		break; /* Continue below */
+		return CMD_SUCCESS;
 	case 5:
 		if (strcmp(argv[3], "priority") != 0 &&
 		    strcmp(argv[3], "qos-class") != 0)
@@ -406,46 +381,18 @@ DEFUN_ATTR(cs7_rt_upd, cs7_rt_upd_cmd,
 		return CMD_WARNING;
 	}
 
-	rt = ss7_route_alloc(rtable, dpc, mask);
-	if (!rt) {
-		vty_out(vty, "%% Cannot allocate new route%s", VTY_NEWLINE);
-		return CMD_WARNING;
-	}
-
-	if ((rc = ss7_route_set_linkset(rt, ls_name)) < 0) {
-		vty_out(vty, "%% Cannot find linkset %s%s", ls_name, VTY_NEWLINE);
-		goto destroy_warning;
-	}
-
 	argind = 3;
 	if (argc > argind && !strcmp(argv[argind], "priority")) {
 		argind++;
-		if (strcmp(argv[argind], "default") != 0)
-			rt->cfg.priority = atoi(argv[argind]);
-		argind++;
+		rt->cfg.priority = atoi(argv[argind++]);
 	}
 
 	if (argc > argind && !strcmp(argv[argind], "qos-class")) {
 		argind++;
-		if (strcmp(argv[argind], "default") != 0)
-			rt->cfg.qos_class = atoi(argv[argind]);
-		argind++;
-	}
-
-	if ((rc = ss7_route_insert(rt)) < 0) {
-		char buf_err[128];
-		strerror_r(-rc, buf_err, sizeof(buf_err));
-		vty_out(vty, "%% Cannot insert route %s/%s to %s: %s (%d)%s",
-			argv[0], argv[1], argv[2],
-			buf_err, rc, VTY_NEWLINE);
-		goto destroy_warning;
+		rt->cfg.qos_class = atoi(argv[argind++]);
 	}
 
 	return CMD_SUCCESS;
-
-destroy_warning:
-	ss7_route_destroy(rt);
-	return CMD_WARNING;
 }
 
 DEFUN_ATTR(cs7_rt_rem, cs7_rt_rem_cmd,
@@ -472,13 +419,13 @@ DEFUN_ATTR(cs7_rt_rem, cs7_rt_rem_cmd,
 		return CMD_WARNING;
 	}
 
-	rt = ss7_route_table_find_route_by_dpc_mask(rtable, dpc, mask);
+	rt = osmo_ss7_route_find_dpc_mask(rtable, dpc, mask);
 	if (!rt) {
 		vty_out(vty, "cannot find route to be deleted%s", VTY_NEWLINE);
 		return CMD_WARNING;
 	}
 
-	ss7_route_destroy(rt);
+	osmo_ss7_route_destroy(rt);
 	return CMD_SUCCESS;
 }
 
@@ -494,7 +441,7 @@ static void write_one_rtable(struct vty *vty, struct osmo_ss7_route_table *rtabl
 			osmo_ss7_pointcode_print(rtable->inst, rt->cfg.pc),
 			osmo_ss7_pointcode_print2(rtable->inst, rt->cfg.mask),
 			rt->cfg.linkset_name);
-		if (rt->cfg.priority != OSMO_SS7_ROUTE_PRIO_DEFAULT)
+		if (rt->cfg.priority)
 			vty_out(vty, " priority %u", rt->cfg.priority);
 		if (rt->cfg.qos_class)
 			vty_out(vty, " qos-class %u", rt->cfg.qos_class);
@@ -1090,9 +1037,9 @@ DEFUN_ATTR(asp_no_remote_ip, asp_no_remote_ip_cmd,
 }
 
 DEFUN_ATTR(asp_qos_clas, asp_qos_class_cmd,
-	   "qos-class " QOS_CLASS_RANGE_STR,
+	   "qos-class <0-255>",
 	   "Specify QoS Class of ASP\n"
-	   QOS_CLASS_RANGE_HELP_STR,
+	   "QoS Class of ASP\n",
 	   CMD_ATTR_NODE_EXIT)
 {
 	struct osmo_ss7_asp *asp = vty->index;
@@ -1951,9 +1898,9 @@ DEFUN_ATTR(as_recov_tout, as_recov_tout_cmd,
 }
 
 DEFUN_ATTR(as_qos_clas, as_qos_class_cmd,
-	   "qos-class " QOS_CLASS_RANGE_STR,
+	   "qos-class <0-255>",
 	   "Specity QoS Class of AS\n"
-	   QOS_CLASS_RANGE_HELP_STR,
+	   "QoS Class of AS\n",
 	   CMD_ATTR_IMMEDIATE)
 {
 	struct osmo_ss7_as *as = vty->index;
@@ -2024,9 +1971,9 @@ static int _rout_key(struct vty *vty,
 	 * (users may change the routing key via VTY during runtime) and then
 	 * putting a new route (see below). */
 	if (cs7_role == CS7_ROLE_ASP) {
-		rt = ss7_route_table_find_route_by_dpc_mask(as->inst->rtable_system, rkey->pc, 0xffffff);
+		rt = osmo_ss7_route_find_dpc_mask(as->inst->rtable_system, rkey->pc, 0xffffff);
 		if (rt)
-			ss7_route_destroy(rt);
+			osmo_ss7_route_destroy(rt);
 	}
 
 	rkey->pc = pc;
@@ -2037,7 +1984,7 @@ static int _rout_key(struct vty *vty,
 
 	/* automatically add new route (see also comment above) */
 	if (cs7_role == CS7_ROLE_ASP) {
-		if (!ss7_route_create(as->inst->rtable_system, rkey->pc, 0xffffff, as->cfg.name)) {
+		if (!osmo_ss7_route_create(as->inst->rtable_system, rkey->pc, 0xffffff, as->cfg.name)) {
 			vty_out(vty, "Cannot create route (pc=%s, linkset=%s) to AS %s", dpc, as->cfg.name, VTY_NEWLINE);
 			return CMD_WARNING;
 		}
@@ -2882,11 +2829,6 @@ static void write_one_cs7(struct vty *vty, struct osmo_ss7_instance *inst, bool
 			osmo_ss7_pointcode_print(inst, inst->cfg.primary_pc),
 			VTY_NEWLINE);
 
-	if (osmo_ss7_pc_is_valid(inst->cfg.secondary_pc)) {
-		vty_out(vty, " secondary-pc %s%s",
-			osmo_ss7_pointcode_print(inst, inst->cfg.secondary_pc), VTY_NEWLINE);
-	}
-
 	if (inst->cfg.permit_dyn_rkm_alloc)
 		vty_out(vty, " xua rkm routing-key-allocation dynamic-permitted%s", VTY_NEWLINE);
 
@@ -3047,7 +2989,6 @@ static void vty_init_shared(void *ctx)
 	install_lib_element(L_CS7_NODE, &cfg_description_cmd);
 	install_lib_element(L_CS7_NODE, &cs7_net_ind_cmd);
 	install_lib_element(L_CS7_NODE, &cs7_point_code_cmd);
-	install_lib_element(L_CS7_NODE, &cs7_secondary_pc_cmd);
 	install_lib_element(L_CS7_NODE, &cs7_pc_format_cmd);
 	install_lib_element(L_CS7_NODE, &cs7_pc_format_def_cmd);
 	install_lib_element(L_CS7_NODE, &cs7_pc_delimiter_cmd);
